@@ -13,17 +13,13 @@ mod connections;
 pub use connections::Destination;
 /// Messages are used for all Communication between Server and Client
 pub mod message;
-/// A Generic Object-Pool that allows for easy reuse of Objects
-/// between actions
-pub(crate) mod objectpool;
 #[cfg(feature = "server")]
 pub mod server;
-/// Provides all the Stream/Queue related functionality
-pub mod streams;
+mod streams;
 
 /// All the Metrics related functionality
 pub mod metrics;
 
 pub(crate) mod general;
-pub use general::{Details, DetailsIP};
+pub use general::Details;
 pub(crate) mod handshake;
