@@ -4,8 +4,5 @@ pub use header::MessageHeader;
 mod kind;
 pub use kind::MessageType;
 
-mod data;
-pub use data::Data;
-
 mod entire;
 pub use entire::Message;
